orca r3518 - in trunk: . test/keystrokes/firefox



Author: joanied
Date: Tue Jan 29 04:00:40 2008
New Revision: 3518
URL: http://svn.gnome.org/viewvc/orca?rev=3518&view=rev

Log:
* test/keystrokes/firefox/xul_role_list_item.py:
  test/keystrokes/firefox/label_guess_bugzilla_search.py:
  test/keystrokes/firefox/xul_role_tree.py:
  test/keystrokes/firefox/html_role_combo_box.py:
  test/keystrokes/firefox/xul_where_am_i_status_bar.py:
  test/keystrokes/firefox/xul_role_tree_table.py:
  test/keystrokes/firefox/html_struct_nav_list_item.py:
  test/keystrokes/firefox/html_struct_nav_lists.py:
  test/keystrokes/firefox/xul_role_check_box.py:
  test/keystrokes/firefox/html_role_lists.py:
  test/keystrokes/firefox/html_struct_nav_blockquote.py:
  test/keystrokes/firefox/xul_where_am_i_dialog.py:
  test/keystrokes/firefox/line_nav_bugzilla_search.py:
  test/keystrokes/firefox/xul_role_page_tab.py:
  test/keystrokes/firefox/xul_role_alert.py:
  Updated regression tests.


Modified:
   trunk/ChangeLog
   trunk/test/keystrokes/firefox/html_role_combo_box.py
   trunk/test/keystrokes/firefox/html_role_lists.py
   trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py
   trunk/test/keystrokes/firefox/html_struct_nav_list_item.py
   trunk/test/keystrokes/firefox/html_struct_nav_lists.py
   trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
   trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
   trunk/test/keystrokes/firefox/xul_role_alert.py
   trunk/test/keystrokes/firefox/xul_role_check_box.py
   trunk/test/keystrokes/firefox/xul_role_list_item.py
   trunk/test/keystrokes/firefox/xul_role_page_tab.py
   trunk/test/keystrokes/firefox/xul_role_tree.py
   trunk/test/keystrokes/firefox/xul_role_tree_table.py
   trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
   trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py

Modified: trunk/test/keystrokes/firefox/html_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_combo_box.py	Tue Jan 29 04:00:40 2008
@@ -172,10 +172,9 @@
 sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Return to collapse combo box",
-    ["BUG? - It would be nice to handle this better", 
-     "BRAILLE LINE:  'WONTFIX Combo'",
-     "     VISIBLE:  'WONTFIX Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test panel'",
+    ["BRAILLE LINE:  'WONTFIX Combo'",
+     "     VISIBLE:  'WONTFIX Combo', cursor=1",
+     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
      "SPEECH OUTPUT: 'Resolution: WONTFIX combo box'"]))
 
 ########################################################################
@@ -264,9 +263,9 @@
 sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Return to collapse combo box",
-    ["BRAILLE LINE:  'Braille Combo'",
-     "     VISIBLE:  'Braille Combo', cursor=1",
-     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test panel'",
+    ["BRAILLE LINE:  'Braille Combo'",
+     "     VISIBLE:  'Braille Combo', cursor=1",
+     "SPEECH OUTPUT: 'Minefield application Combo Box Regression Test - Minefield frame Combo Box Regression Test internal frame'",
      "SPEECH OUTPUT: 'Component Braille combo box'"]))
 
 ########################################################################
@@ -277,8 +276,7 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BUG? - We're not handling combo boxes in HTML very well in where am I", 
-     "BRAILLE LINE:  'Braille Combo'",
+    ["BRAILLE LINE:  'Braille Combo'",
      "     VISIBLE:  'Braille Combo', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'combo box'",

Modified: trunk/test/keystrokes/firefox/html_role_lists.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_lists.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_lists.py	Tue Jan 29 04:00:40 2008
@@ -55,114 +55,113 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BUG? - For some reason in the harness, list numbers are all '0'. They are correct in actual use. I'm only marking this issue once.",
-     "BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some sense of priority, even if it is artificial'",
-     "     VISIBLE:  '0. arrange long and arbitrary li', cursor=1",
-     "SPEECH OUTPUT: '0. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some sense of priority, even if it is artificial'"]))
+    ["BRAILLE LINE:  '2. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some'",
+     "     VISIBLE:  '2. arrange long and arbitrary li', cursor=1",
+     "SPEECH OUTPUT: '2. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. look really cool when we carry them around on yellow Post-Itstm.'",
-     "     VISIBLE:  '0. look really cool when we carr', cursor=1",
-     "SPEECH OUTPUT: '0. look really cool when we carry them around on yellow Post-Itstm.'"]))
+    ["BRAILLE LINE:  'sense of priority, even if it is artificial'",
+     "     VISIBLE:  'sense of priority, even if it is', cursor=1",
+     "SPEECH OUTPUT: 'sense of priority, even if it is artificial'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. and that other thing I keep forgetting.'",
-     "     VISIBLE:  '0. and that other thing I keep f', cursor=1",
-     "SPEECH OUTPUT: '0. and that other thing I keep forgetting.'"]))
+    ["BRAILLE LINE:  '3. look really cool when we carry them around on yellow Post-Itstm.'",
+     "     VISIBLE:  '3. look really cool when we carr', cursor=1",
+     "SPEECH OUTPUT: '3. look really cool when we carry them around on yellow Post-Itstm.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'Your ordered lists can start at a strange number, like:'",
-     "     VISIBLE:  'Your ordered lists can start at ', cursor=1",
-     "SPEECH OUTPUT: 'Your ordered lists can start at a strange number, like:'"]))
+    ["BRAILLE LINE:  '4. and that other thing I keep forgetting.'",
+     "     VISIBLE:  '4. and that other thing I keep f', cursor=1",
+     "SPEECH OUTPUT: '4. and that other thing I keep forgetting.'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. And use roman numerals,'",
-     "     VISIBLE:  '0. And use roman numerals,', cursor=1",
-     "SPEECH OUTPUT: '0. And use roman numerals,'"]))
+    ["BRAILLE LINE:  'Your ordered lists can start at a strange number, like:'",
+     "     VISIBLE:  'Your ordered lists can start at ', cursor=1",
+     "SPEECH OUTPUT: 'Your ordered lists can start at a strange number, like:'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. You might try using letters as well,'",
-     "     VISIBLE:  '0. You might try using letters a', cursor=1",
-     "SPEECH OUTPUT: '0. You might try using letters as well,'"]))
+    ["BRAILLE LINE:  'VI. And use roman numerals,'",
+     "     VISIBLE:  'VI. And use roman numerals,', cursor=1",
+     "SPEECH OUTPUT: 'VI. And use roman numerals,'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. Maybe you prefer Big Letters,'",
-     "     VISIBLE:  '0. Maybe you prefer Big Letters,', cursor=1",
-     "SPEECH OUTPUT: '0. Maybe you prefer Big Letters,'"]))
+    ["BRAILLE LINE:  'g. You might try using letters as well,'",
+     "     VISIBLE:  'g. You might try using letters a', cursor=1",
+     "SPEECH OUTPUT: 'g. You might try using letters as well,'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. or small roman numerals'",
-     "     VISIBLE:  '0. or small roman numerals', cursor=1",
-     "SPEECH OUTPUT: '0. or small roman numerals'"]))
+    ["BRAILLE LINE:  'H. Maybe you prefer Big Letters,'",
+     "     VISIBLE:  'H. Maybe you prefer Big Letters,', cursor=1",
+     "SPEECH OUTPUT: 'H. Maybe you prefer Big Letters,'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'â But discs belong to unordered lists'",
-     "     VISIBLE:  'â But discs belong to unordere', cursor=1",
-     "SPEECH OUTPUT: 'â But discs belong to unordered lists'"]))
+    ["BRAILLE LINE:  'ix. or small roman numerals'",
+     "     VISIBLE:  'ix. or small roman numerals', cursor=1",
+     "SPEECH OUTPUT: 'ix. or small roman numerals'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  '0. Though you can set the value in a list item!'",
-     "     VISIBLE:  '0. Though you can set the value ', cursor=1",
-     "SPEECH OUTPUT: '0. Though you can set the value in a list item!'"]))
+    ["BRAILLE LINE:  'â But discs belong to unordered lists'",
+     "     VISIBLE:  'â But discs belong to unordere', cursor=1",
+     "SPEECH OUTPUT: 'â But discs belong to unordered lists'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'Unordered list:'",
-     "     VISIBLE:  'Unordered list:', cursor=1",
-     "SPEECH OUTPUT: 'Unordered list:'"]))
+    ["BRAILLE LINE:  '50. Though you can set the value in a list item!'",
+     "     VISIBLE:  '50. Though you can set the value', cursor=1",
+     "SPEECH OUTPUT: '50. Though you can set the value in a list item!'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  '0. Though you can set the value in a list item!'",
-     "     VISIBLE:  '0. Though you can set the value ', cursor=1",
-     "SPEECH OUTPUT: '0. Though you can set the value in a list item!'"]))
+    ["BRAILLE LINE:  'â But discs belong to unordered lists'",
+     "     VISIBLE:  'â But discs belong to unordere', cursor=1",
+     "SPEECH OUTPUT: 'â But discs belong to unordered lists'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up", 
-    ["BRAILLE LINE:  'â But discs belong to unordered lists'",
-     "     VISIBLE:  'â But discs belong to unordere', cursor=1",
-     "SPEECH OUTPUT: 'â But discs belong to unordered lists'"]))
+    ["BRAILLE LINE:  'ix. or small roman numerals'",
+     "     VISIBLE:  'ix. or small roman numerals', cursor=1",
+     "SPEECH OUTPUT: 'ix. or small roman numerals'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  
@@ -172,11 +171,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'â But discs belong to unordered lists'",
-     "     VISIBLE:  'â But discs belong to unordere', cursor=1",
-     "SPEECH OUTPUT: 'list item'",
-     "SPEECH OUTPUT: 'â But discs belong to unordered lists'",
-     "SPEECH OUTPUT: 'item 5 of 6'"]))
+    ["BRAILLE LINE:  'ix. or small roman numerals'",
+     "     VISIBLE:  'ix. or small roman numerals', cursor=1",
+     "SPEECH OUTPUT: 'list item'",
+     "SPEECH OUTPUT: 'ix. or small roman numerals'",
+     "SPEECH OUTPUT: 'item 4 of 6'"]))
 
 ########################################################################
 # Move to the location bar by pressing Control+L.  When it has focus

Modified: trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py	Tue Jan 29 04:00:40 2008
@@ -124,8 +124,7 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I",
-    ["BUG? - Technically, this is correct.  But should we indicate we're in a blockquote?",
-     "BRAILLE LINE:  'Now old lady, you have one last chance. Confess the heinous sin of heresy, reject the works of the'",
+    ["BRAILLE LINE:  'Now old lady, you have one last chance. Confess the heinous sin of heresy, reject the works of the'",
      "     VISIBLE:  'Now old lady, you have one last ', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'paragraph'",

Modified: trunk/test/keystrokes/firefox/html_struct_nav_list_item.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_list_item.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_list_item.py	Tue Jan 29 04:00:40 2008
@@ -47,12 +47,10 @@
 sequence.append(KeyComboAction("l"))
 sequence.append(utils.AssertPresentationAction(
     "l to first list", 
-    ["BUG? - For some reason in the harness, list numbers are all '0'. They are correct in actual use. I'm only marking this issue once.",
-    
-     "BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: 'List with 4 items'",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: 'List with 4 items'",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 ########################################################################
 # Press L to move to the second list.
@@ -61,10 +59,10 @@
 sequence.append(KeyComboAction("l"))
 sequence.append(utils.AssertPresentationAction(
     "l to second list", 
-    ["BRAILLE LINE:  '0. And use roman numerals,'",
-     "     VISIBLE:  '0. And use roman numerals,', cursor=1",
-     "SPEECH OUTPUT: 'List with 6 items'",
-     "SPEECH OUTPUT: '0. And use roman numerals,'"]))
+    ["BRAILLE LINE:  'VI. And use roman numerals,'",
+     "     VISIBLE:  'VI. And use roman numerals,', cursor=1",
+     "SPEECH OUTPUT: 'List with 6 items'",
+     "SPEECH OUTPUT: 'VI. And use roman numerals,'"]))
 
 ########################################################################
 # Press L to move to the third list.
@@ -198,18 +196,18 @@
 sequence.append(KeyComboAction("i"))
 sequence.append(utils.AssertPresentationAction(
     "i should wrap to top", 
-    ["BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: 'Wrapping to top.'",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: 'Wrapping to top.'",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("i"))
 sequence.append(utils.AssertPresentationAction(
     "i in first list", 
-    ["BRAILLE LINE:  '0. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some sense of priority, even if it is artificial'",
-     "     VISIBLE:  '0. arrange long and arbitrary li', cursor=1",
-     "SPEECH OUTPUT: '0. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some sense of priority, even if it is artificial'"]))
+    ["BRAILLE LINE:  '2. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some'",
+     "     VISIBLE:  '2. arrange long and arbitrary li', cursor=1",
+     "SPEECH OUTPUT: '2. arrange long and arbitrary lines of text into ordered lists that are pleasing to the eye and suggest some'"]))
 
 ########################################################################
 # Now reverse our direction, but just for a few items.
@@ -218,9 +216,9 @@
 sequence.append(KeyComboAction("<Shift>i"))
 sequence.append(utils.AssertPresentationAction(
     "shift + i in first list", 
-    ["BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>i"))

Modified: trunk/test/keystrokes/firefox/html_struct_nav_lists.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_lists.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_lists.py	Tue Jan 29 04:00:40 2008
@@ -47,12 +47,10 @@
 sequence.append(KeyComboAction("l"))
 sequence.append(utils.AssertPresentationAction(
     "l to first list", 
-    ["BUG? - For some reason in the harness, list numbers are all '0'. They are correct in actual use. I'm only marking this issue once.",
-    
-     "BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: 'List with 4 items'",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: 'List with 4 items'",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 ########################################################################
 # Press L to move to the second list.
@@ -61,10 +59,10 @@
 sequence.append(KeyComboAction("l"))
 sequence.append(utils.AssertPresentationAction(
     "l to second list", 
-    ["BRAILLE LINE:  '0. And use roman numerals,'",
-     "     VISIBLE:  '0. And use roman numerals,', cursor=1",
-     "SPEECH OUTPUT: 'List with 6 items'",
-     "SPEECH OUTPUT: '0. And use roman numerals,'"]))
+    ["BRAILLE LINE:  'VI. And use roman numerals,'",
+     "     VISIBLE:  'VI. And use roman numerals,', cursor=1",
+     "SPEECH OUTPUT: 'List with 6 items'",
+     "SPEECH OUTPUT: 'VI. And use roman numerals,'"]))
 
 ########################################################################
 # Press L to move to the third list.
@@ -165,11 +163,11 @@
 sequence.append(KeyComboAction("l"))
 sequence.append(utils.AssertPresentationAction(
     "l - should wrap to top", 
-    ["BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: 'Wrapping to top.'",
-     "SPEECH OUTPUT: 'List with 4 items'",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: 'Wrapping to top.'",
+     "SPEECH OUTPUT: 'List with 4 items'",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 ########################################################################
 # Pressing Shift+L should result in our wrapping to the bottom
@@ -252,19 +250,19 @@
 sequence.append(KeyComboAction("<Shift>l"))
 sequence.append(utils.AssertPresentationAction(
     "shift + l", 
-    ["BRAILLE LINE:  '0. And use roman numerals,'",
-     "     VISIBLE:  '0. And use roman numerals,', cursor=1",
-     "SPEECH OUTPUT: 'List with 6 items'",
-     "SPEECH OUTPUT: '0. And use roman numerals,'"]))
+    ["BRAILLE LINE:  'VI. And use roman numerals,'",
+     "     VISIBLE:  'VI. And use roman numerals,', cursor=1",
+     "SPEECH OUTPUT: 'List with 6 items'",
+     "SPEECH OUTPUT: 'VI. And use roman numerals,'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>l"))
 sequence.append(utils.AssertPresentationAction(
     "shift + l", 
-    ["BRAILLE LINE:  '0. remember what the heck we are doing each day'",
-     "     VISIBLE:  '0. remember what the heck we are', cursor=1",
-     "SPEECH OUTPUT: 'List with 4 items'",
-     "SPEECH OUTPUT: '0. remember what the heck we are doing each day'"]))
+    ["BRAILLE LINE:  '1. remember what the heck we are doing each day'",
+     "     VISIBLE:  '1. remember what the heck we are', cursor=1",
+     "SPEECH OUTPUT: 'List with 4 items'",
+     "SPEECH OUTPUT: '1. remember what the heck we are doing each day'"]))
 
 ########################################################################
 # Move to the location bar by pressing Control+L.  When it has focus

Modified: trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	Tue Jan 29 04:00:40 2008
@@ -399,8 +399,7 @@
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
-    ["BUG? - It would be nice to not guess the text that follows the combobox in this case.",
-     "BRAILLE LINE:  'Only include Combo bugs numbered:  $l'",
+    ["BRAILLE LINE:  'Only include Combo bugs numbered:  $l'",
      "     VISIBLE:  'Only include Combo bugs numbered', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'bugs numbered: Only include combo box'"]))

Modified: trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	Tue Jan 29 04:00:40 2008
@@ -287,41 +287,41 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '<x> CheckBox the bug assignee'",
-     "     VISIBLE:  '<x> CheckBox the bug assignee', cursor=1",
-     "SPEECH OUTPUT: 'the bug assignee  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the bug assignee'",
+     "     VISIBLE:  '<x> CheckBox  the bug assignee', cursor=1",
+     "SPEECH OUTPUT: 'the bug assignee check box checked  the bug assignee'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox the reporter'",
-     "     VISIBLE:  '< > CheckBox the reporter', cursor=1",
-     "SPEECH OUTPUT: 'the reporter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  the reporter'",
+     "     VISIBLE:  '< > CheckBox  the reporter', cursor=1",
+     "SPEECH OUTPUT: 'the reporter check box not checked  the reporter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox the QA contact'",
-     "     VISIBLE:  '< > CheckBox the QA contact', cursor=1",
-     "SPEECH OUTPUT: 'the QA contact  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  the QA contact'",
+     "     VISIBLE:  '< > CheckBox  the QA contact', cursor=1",
+     "SPEECH OUTPUT: 'the QA contact check box not checked  the QA contact'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox a CC list member'",
-     "     VISIBLE:  '< > CheckBox a CC list member', cursor=1",
-     "SPEECH OUTPUT: 'a CC list member  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a CC list member'",
+     "     VISIBLE:  '< > CheckBox  a CC list member', cursor=1",
+     "SPEECH OUTPUT: 'a CC list member check box not checked  a CC list member'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox a commenter'",
-     "     VISIBLE:  '< > CheckBox a commenter', cursor=1",
-     "SPEECH OUTPUT: 'a commenter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a commenter'",
+     "     VISIBLE:  '< > CheckBox  a commenter', cursor=1",
+     "SPEECH OUTPUT: 'a commenter check box not checked  a commenter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
@@ -351,41 +351,41 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '<x> CheckBox the bug assignee'",
-     "     VISIBLE:  '<x> CheckBox the bug assignee', cursor=1",
-     "SPEECH OUTPUT: 'the bug assignee  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the bug assignee'",
+     "     VISIBLE:  '<x> CheckBox  the bug assignee', cursor=1",
+     "SPEECH OUTPUT: 'the bug assignee check box checked  the bug assignee'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '<x> CheckBox the reporter'",
-     "     VISIBLE:  '<x> CheckBox the reporter', cursor=1",
-     "SPEECH OUTPUT: 'the reporter  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the reporter'",
+     "     VISIBLE:  '<x> CheckBox  the reporter', cursor=1",
+     "SPEECH OUTPUT: 'the reporter check box checked  the reporter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '<x> CheckBox the QA contact'",
-     "     VISIBLE:  '<x> CheckBox the QA contact', cursor=1",
-     "SPEECH OUTPUT: 'the QA contact  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the QA contact'",
+     "     VISIBLE:  '<x> CheckBox  the QA contact', cursor=1",
+     "SPEECH OUTPUT: 'the QA contact check box checked  the QA contact'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '<x> CheckBox a CC list member'",
-     "     VISIBLE:  '<x> CheckBox a CC list member', cursor=1",
-     "SPEECH OUTPUT: 'a CC list member  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  a CC list member'",
+     "     VISIBLE:  '<x> CheckBox  a CC list member', cursor=1",
+     "SPEECH OUTPUT: 'a CC list member check box checked  a CC list member'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox a commenter'",
-     "     VISIBLE:  '< > CheckBox a commenter', cursor=1",
-     "SPEECH OUTPUT: 'a commenter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a commenter'",
+     "     VISIBLE:  '< > CheckBox  a commenter', cursor=1",
+     "SPEECH OUTPUT: 'a commenter check box not checked  a commenter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
@@ -551,9 +551,9 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'ÂÂÂ < > CheckBox and remember these as my default search options'",
-     "     VISIBLE:  'ÂÂÂ < > CheckBox and remember', cursor=1",
-     "SPEECH OUTPUT: 'ÂÂÂ and remember these as my default search options  check box not checked'"]))
+    ["BRAILLE LINE:  'ÂÂÂ < > CheckBox  and remember these as my default search options'",
+     "     VISIBLE:  'ÂÂÂ < > CheckBox  and remembe', cursor=1",
+     "SPEECH OUTPUT: 'ÂÂÂ check box not checked  and remember these as my default search options'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
@@ -575,9 +575,9 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  '< > CheckBox Not (negate this whole chart)'",
-     "     VISIBLE:  '< > CheckBox Not (negate this wh', cursor=1",
-     "SPEECH OUTPUT: 'Not (negate this whole chart)  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  Not (negate this whole chart)'",
+     "     VISIBLE:  '< > CheckBox  Not (negate this w', cursor=1",
+     "SPEECH OUTPUT: 'Not (negate this whole chart) check box not checked  Not (negate this whole chart)'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
@@ -642,9 +642,9 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox Not (negate this whole chart)'",
-     "     VISIBLE:  '< > CheckBox Not (negate this wh', cursor=1",
-     "SPEECH OUTPUT: 'Not (negate this whole chart)  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  Not (negate this whole chart)'",
+     "     VISIBLE:  '< > CheckBox  Not (negate this w', cursor=1",
+     "SPEECH OUTPUT: 'Not (negate this whole chart) check box not checked  Not (negate this whole chart)'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -666,9 +666,9 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'ÂÂÂ < > CheckBox and remember these as my default search options'",
-     "     VISIBLE:  'ÂÂÂ < > CheckBox and remember', cursor=1",
-     "SPEECH OUTPUT: 'ÂÂÂ and remember these as my default search options  check box not checked'"]))
+    ["BRAILLE LINE:  'ÂÂÂ < > CheckBox  and remember these as my default search options'",
+     "     VISIBLE:  'ÂÂÂ < > CheckBox  and remembe', cursor=1",
+     "SPEECH OUTPUT: 'ÂÂÂ check box not checked  and remember these as my default search options'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -826,41 +826,41 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox a commenter'",
-     "     VISIBLE:  '< > CheckBox a commenter', cursor=1",
-     "SPEECH OUTPUT: 'a commenter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a commenter'",
+     "     VISIBLE:  '< > CheckBox  a commenter', cursor=1",
+     "SPEECH OUTPUT: 'a commenter check box not checked  a commenter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '<x> CheckBox a CC list member'",
-     "     VISIBLE:  '<x> CheckBox a CC list member', cursor=1",
-     "SPEECH OUTPUT: 'a CC list member  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  a CC list member'",
+     "     VISIBLE:  '<x> CheckBox  a CC list member', cursor=1",
+     "SPEECH OUTPUT: 'a CC list member check box checked  a CC list member'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '<x> CheckBox the QA contact'",
-     "     VISIBLE:  '<x> CheckBox the QA contact', cursor=1",
-     "SPEECH OUTPUT: 'the QA contact  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the QA contact'",
+     "     VISIBLE:  '<x> CheckBox  the QA contact', cursor=1",
+     "SPEECH OUTPUT: 'the QA contact check box checked  the QA contact'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '<x> CheckBox the reporter'",
-     "     VISIBLE:  '<x> CheckBox the reporter', cursor=1",
-     "SPEECH OUTPUT: 'the reporter  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the reporter'",
+     "     VISIBLE:  '<x> CheckBox  the reporter', cursor=1",
+     "SPEECH OUTPUT: 'the reporter check box checked  the reporter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '<x> CheckBox the bug assignee'",
-     "     VISIBLE:  '<x> CheckBox the bug assignee', cursor=1",
-     "SPEECH OUTPUT: 'the bug assignee  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the bug assignee'",
+     "     VISIBLE:  '<x> CheckBox  the bug assignee', cursor=1",
+     "SPEECH OUTPUT: 'the bug assignee check box checked  the bug assignee'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
@@ -890,41 +890,41 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox a commenter'",
-     "     VISIBLE:  '< > CheckBox a commenter', cursor=1",
-     "SPEECH OUTPUT: 'a commenter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a commenter'",
+     "     VISIBLE:  '< > CheckBox  a commenter', cursor=1",
+     "SPEECH OUTPUT: 'a commenter check box not checked  a commenter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox a CC list member'",
-     "     VISIBLE:  '< > CheckBox a CC list member', cursor=1",
-     "SPEECH OUTPUT: 'a CC list member  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  a CC list member'",
+     "     VISIBLE:  '< > CheckBox  a CC list member', cursor=1",
+     "SPEECH OUTPUT: 'a CC list member check box not checked  a CC list member'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox the QA contact'",
-     "     VISIBLE:  '< > CheckBox the QA contact', cursor=1",
-     "SPEECH OUTPUT: 'the QA contact  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  the QA contact'",
+     "     VISIBLE:  '< > CheckBox  the QA contact', cursor=1",
+     "SPEECH OUTPUT: 'the QA contact check box not checked  the QA contact'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '< > CheckBox the reporter'",
-     "     VISIBLE:  '< > CheckBox the reporter', cursor=1",
-     "SPEECH OUTPUT: 'the reporter  check box not checked'"]))
+    ["BRAILLE LINE:  '< > CheckBox  the reporter'",
+     "     VISIBLE:  '< > CheckBox  the reporter', cursor=1",
+     "SPEECH OUTPUT: 'the reporter check box not checked  the reporter'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  '<x> CheckBox the bug assignee'",
-     "     VISIBLE:  '<x> CheckBox the bug assignee', cursor=1",
-     "SPEECH OUTPUT: 'the bug assignee  check box checked'"]))
+    ["BRAILLE LINE:  '<x> CheckBox  the bug assignee'",
+     "     VISIBLE:  '<x> CheckBox  the bug assignee', cursor=1",
+     "SPEECH OUTPUT: 'the bug assignee check box checked  the bug assignee'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))

Modified: trunk/test/keystrokes/firefox/xul_role_alert.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_alert.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_alert.py	Tue Jan 29 04:00:40 2008
@@ -55,7 +55,7 @@
      "     VISIBLE:  'about:blank HtmlPane', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Minefield frame'",
-     "SPEECH OUTPUT: 'about:blank panel'",
+     "SPEECH OUTPUT: 'about:blank internal frame'",
      "SPEECH OUTPUT: 'about:blank html content'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_role_check_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_list_item.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_list_item.py	Tue Jan 29 04:00:40 2008
@@ -16,44 +16,10 @@
 ########################################################################
 # Open the "Edit" menu and Up Arrow to Preferences, then press Return.
 #
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>e"))
-sequence.append(utils.AssertPresentationAction(
-    "Edit menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Edit Menu'",
-     "     VISIBLE:  'Edit Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Select All(Control A)'",
-     "     VISIBLE:  'Select All(Control A)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Edit menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Select All Control A'"]))
-
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "Up Arrow in Edit menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Preferences'",
-     "     VISIBLE:  'Preferences', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Preferences'"]))
-
-sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Return"))
-sequence.append(utils.AssertPresentationAction(
-    "Press Return to make the Preferences dialog appear",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame'",
-     "     VISIBLE:  'Minefield Preferences Frame', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Main ListItem'",
-     "     VISIBLE:  'Main ListItem', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Minefield Preferences frame'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Main list item'"]))
+sequence.append(WaitForWindowActivate("Minefield Preferences",None))
 
 ########################################################################
 # Press Right Arrow to move forward list item by list item.
@@ -65,7 +31,8 @@
     ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Tabs ListItem'",
      "     VISIBLE:  'Tabs ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Tabs list item'"]))
+     "SPEECH OUTPUT: 'Tabs list item'",
+     "SPEECH OUTPUT: 'New pages should be opened in:'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Right"))
@@ -76,15 +43,6 @@
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Content list item'"]))
 
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Right"))
-sequence.append(utils.AssertPresentationAction(
-    "Right Arrow in list",
-    ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Applications ListItem'",
-     "     VISIBLE:  'Applications ListItem', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Applications list item'"]))
-
 ########################################################################
 # Press Left Arrow to move backward list item by list item.
 #
@@ -92,15 +50,6 @@
 sequence.append(KeyComboAction("Left"))
 sequence.append(utils.AssertPresentationAction(
     "Left Arrow in list",
-    ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Content ListItem'",
-     "     VISIBLE:  'Content ListItem', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Content list item'"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Left"))
-sequence.append(utils.AssertPresentationAction(
-    "Left Arrow in list",
     ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Tabs ListItem'",
      "     VISIBLE:  'Tabs ListItem', cursor=1",
      "SPEECH OUTPUT: ''",

Modified: trunk/test/keystrokes/firefox/xul_role_page_tab.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_tree.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_tree.py	Tue Jan 29 04:00:40 2008
@@ -53,7 +53,8 @@
     ["BRAILLE LINE:  'Minefield Application Library Frame Tree All Bookmarks ListItem'",
      "     VISIBLE:  'All Bookmarks ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'All Bookmarks list item expanded'"]))
+     "SPEECH OUTPUT: 'All Bookmarks list item expanded'",
+     "SPEECH OUTPUT: 'tree level 1'"]))
 
 ########################################################################
 # Press Down Arrow twice to give focus to the Bookmarks Menu list item.

Modified: trunk/test/keystrokes/firefox/xul_role_tree_table.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_tree_table.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_tree_table.py	Tue Jan 29 04:00:40 2008
@@ -53,7 +53,9 @@
     ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable Name ColumnHeader Bookmarks Menu   TREE LEVEL 1'",
      "     VISIBLE:  'Bookmarks Menu   TREE LEVEL 1', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Bookmarks Menu  '"]))
+     "SPEECH OUTPUT: 'Name column header'",
+     "SPEECH OUTPUT: 'Bookmarks Menu  '",
+     "SPEECH OUTPUT: 'tree level 1'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	Tue Jan 29 04:00:40 2008
@@ -70,7 +70,7 @@
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
      "BRAILLE LINE:  'Who expects the Spanish Inquisition? Button'",
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
-     "SPEECH OUTPUT: 'Status Bar Regression Test - Minefield'",
+     "SPEECH OUTPUT: 'Minefield'",
      "SPEECH OUTPUT: 'NOBODY expects the Spanish Inquisition!'"]))
 
 ########################################################################



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/test/keystrokes/firefox/xul_role_check_box.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_check_box.py	Tue Jan 29 04:00:40 2008
@@ -14,51 +14,46 @@
 sequence.append(WaitForWindowActivate("Minefield",None))
 
 ########################################################################
 # Open the "File" menu and press U for the Page Setup dialog
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>f"))
+
+sequence.append(KeyComboAction("p"))
+sequence.append(WaitForWindowActivate("Print",None))
+
+########################################################################
+# Right Arrow until we're at the Options tab 
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
-    "File menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar File Menu'",
-     "     VISIBLE:  'File Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar New Window(Control N)'",
-     "     VISIBLE:  'New Window(Control N)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'File menu'",
+    "Right Arrow to Page Setup",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Page Setup Page'",
+     "     VISIBLE:  'Page Setup Page', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'New Window Control N'"]))
+     "SPEECH OUTPUT: 'Page Setup page'"]))
 
 sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("u"))
+sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
-    "u for Page Setup",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog'",
-     "     VISIBLE:  'Page Setup Dialog', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
+    "Right Arrow to Options",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Options Page'",
+     "     VISIBLE:  'Options Page', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Page Setup %'",
-     "SPEECH OUTPUT: 'Format panel Orientation: panel'",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
- 
-sequence.append(WaitForWindowActivate("Page Setup",None))
+     "SPEECH OUTPUT: 'Options page'"]))
 
 ########################################################################
-# In the Page Setup dialog, tab to the first check box. 
+# Tab to the Ignore Scaling and Shrink to Fit Page Width checkbox.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "Tab to checkbox",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel <x> Shrink To Fit Page Width CheckBox'",
-     "     VISIBLE:  '<x> Shrink To Fit Page Width Che', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList Options Page <x> Ignore Scaling and Shrink To Fit Page Width CheckBox'",
+     "     VISIBLE:  '<x> Ignore Scaling and Shrink To', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Shrink To Fit Page Width check box checked'"]))
+     "SPEECH OUTPUT: 'Ignore Scaling and Shrink To Fit Page Width check box checked'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -68,10 +63,10 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel <x> Shrink To Fit Page Width CheckBox'",
-     "     VISIBLE:  '<x> Shrink To Fit Page Width Che', cursor=1",
-     "SPEECH OUTPUT: 'Shrink To Fit Page Width check box checked'",
-     "SPEECH OUTPUT: ''"]))
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList Options Page <x> Ignore Scaling and Shrink To Fit Page Width CheckBox'",
+     "     VISIBLE:  '<x> Ignore Scaling and Shrink To', cursor=1",
+     "SPEECH OUTPUT: 'Ignore Scaling and Shrink To Fit Page Width check box checked'",
+     "SPEECH OUTPUT: 'Alt h'"]))
 
 ########################################################################
 # Toggle the state of the check box by pressing Space. 
@@ -80,9 +75,9 @@
 sequence.append(TypeAction(" "))
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
-    "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel < > Shrink To Fit Page Width CheckBox'",
-     "     VISIBLE:  '< > Shrink To Fit Page Width Che', cursor=1",
+    "Toggle the state with space", 
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList Options Page < > Ignore Scaling and Shrink To Fit Page Width CheckBox'",
+     "     VISIBLE:  '< > Ignore Scaling and Shrink To', cursor=1",
      "SPEECH OUTPUT: 'not checked'"]))
 
 ########################################################################
@@ -93,10 +88,10 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel < > Shrink To Fit Page Width CheckBox'",
-     "     VISIBLE:  '< > Shrink To Fit Page Width Che', cursor=1",
-     "SPEECH OUTPUT: 'Shrink To Fit Page Width check box not checked'",
-     "SPEECH OUTPUT: ''"]))
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList Options Page < > Ignore Scaling and Shrink To Fit Page Width CheckBox'",
+     "     VISIBLE:  '< > Ignore Scaling and Shrink To', cursor=1",
+     "SPEECH OUTPUT: 'Ignore Scaling and Shrink To Fit Page Width check box not checked'",
+     "SPEECH OUTPUT: 'Alt h'"]))
 
 ########################################################################
 # Toggle the state of the check box by pressing Space. 
@@ -105,9 +100,9 @@
 sequence.append(TypeAction(" "))
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
-    "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel <x> Shrink To Fit Page Width CheckBox'",
-     "     VISIBLE:  '<x> Shrink To Fit Page Width Che', cursor=1",
+    "Toggle the state with space", 
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList Options Page <x> Ignore Scaling and Shrink To Fit Page Width CheckBox'",
+     "     VISIBLE:  '<x> Ignore Scaling and Shrink To', cursor=1",
      "SPEECH OUTPUT: 'checked'"]))
 
 ########################################################################
@@ -14,51 +14,46 @@
 
 ########################################################################
-# Open the "File" menu and press U for the Page Setup dialog
+# Open the "File" menu and press P for the Print dialog
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_role_list_item.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_page_tab.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_page_tab.py	Tue Jan 29 04:00:40 2008
@@ -14,51 +14,13 @@
 sequence.append(WaitForWindowActivate("Minefield",None))
 
 ########################################################################
 # Open the "File" menu and press U for the Page Setup dialog
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>f"))
-sequence.append(utils.AssertPresentationAction(
-    "File menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar File Menu'",
-     "     VISIBLE:  'File Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar New Window(Control N)'",
-     "     VISIBLE:  'New Window(Control N)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'New Window Control N'"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("u"))
-sequence.append(utils.AssertPresentationAction(
-    "u for Page Setup",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog'",
-     "     VISIBLE:  'Page Setup Dialog', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Page Setup %'",
-     "SPEECH OUTPUT: 'Format panel Orientation: panel'",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
- 
-sequence.append(WaitForWindowActivate("Page Setup",None))
 
-########################################################################
-# In the Page Setup dialog, shift+tab once to move to the page tabs.
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
-sequence.append(utils.AssertPresentationAction(
-    "Shift+Tab to page tabs",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Format & Options Page'",
-     "     VISIBLE:  'Format & Options Page', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Format & Options page'"]))
+sequence.append(KeyComboAction("p"))
+sequence.append(WaitForWindowActivate("Print",None))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -68,11 +30,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Format & Options Page'",
-     "     VISIBLE:  'Format & Options Page', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog General Page'",
+     "     VISIBLE:  'General Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
-     "SPEECH OUTPUT: 'Format & Options page'",
-     "SPEECH OUTPUT: 'item 1 of 2'",
+     "SPEECH OUTPUT: 'General page'",
+     "SPEECH OUTPUT: 'item 1 of 3'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################
@@ -82,10 +44,10 @@
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Right Arrow to second page tab",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Margins & Header/Footer Page'",
-     "     VISIBLE:  'Margins & Header/Footer Page', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Page Setup Page'",
+     "     VISIBLE:  'Page Setup Page', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Margins & Header/Footer page'"]))
+     "SPEECH OUTPUT: 'Page Setup page'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -95,11 +57,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Margins & Header/Footer Page'",
-     "     VISIBLE:  'Margins & Header/Footer Page', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog Page Setup Page'",
+     "     VISIBLE:  'Page Setup Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
-     "SPEECH OUTPUT: 'Margins & Header/Footer page'",
-     "SPEECH OUTPUT: 'item 2 of 2'",
+     "SPEECH OUTPUT: 'Page Setup page'",
+     "SPEECH OUTPUT: 'item 2 of 3'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################
@@ -109,10 +71,10 @@
 sequence.append(KeyComboAction("Left"))
 sequence.append(utils.AssertPresentationAction(
     "Left Arrow to first page tab",
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog Format & Options Page'",
-     "     VISIBLE:  'Format & Options Page', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog General Page'",
+     "     VISIBLE:  'General Page', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Format & Options page'"]))
+     "SPEECH OUTPUT: 'General page'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Escape and wait for the location bar
@@ -14,51 +14,13 @@
 
 ########################################################################
-# Open the "File" menu and press U for the Page Setup dialog
+# Open the "File" menu and press P for the Print dialog
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_role_tree.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	Tue Jan 29 04:00:40 2008
@@ -15,39 +15,13 @@
 sequence.append(WaitForWindowActivate("Minefield", None))
 
 ########################################################################
 # Open the "File" menu and press U for the Page Setup dialog
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Alt>f"))
-sequence.append(utils.AssertPresentationAction(
-    "File menu",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar File Menu'",
-     "     VISIBLE:  'File Menu', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar New Window(Control N)'",
-     "     VISIBLE:  'New Window(Control N)', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'New Window Control N'"]))
 
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("u"))
-sequence.append(utils.AssertPresentationAction(
-    "u for Page Setup",
-    ["BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar AutoComplete Location  $l'",
-     "     VISIBLE:  'Location  $l', cursor=10",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog'",
-     "     VISIBLE:  'Page Setup Dialog', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
-     "SPEECH OUTPUT: 'Location text '",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Page Setup %'",
-     "SPEECH OUTPUT: 'Format panel Orientation: panel'",
-     "SPEECH OUTPUT: 'Portrait selected radio button'"]))
- 
-sequence.append(WaitForWindowActivate("Page Setup", None))
+sequence.append(KeyComboAction("p"))
+sequence.append(WaitForWindowActivate("Print",None))
 
 ########################################################################
 # Read the title bar with Orca+KP_ENTER
@@ -59,9 +33,16 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Title Bar", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Page Setup'"]))
+    ["BRAILLE LINE:  'Minefield Application Print Dialog General Page'",
+     "     VISIBLE:  'General Page', cursor=1",
+     "SPEECH OUTPUT: 'Print'"]))
+
+########################################################################
+# Tab once to select an option so that the default button will be
+# available.
+#
+sequence.append(KeyComboAction("Tab"))
+sequence.append(PauseAction(3000))
 
 ########################################################################
 # Obtain the default button with Orca+KP_ENTER double clicked.
@@ -74,12 +55,12 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Default button", 
-    ["BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
-     "     VISIBLE:  '&=y Portrait RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Page Setup'",
-     "SPEECH OUTPUT: 'Default button is OK'"]))
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table  Print to File  '",
+     "     VISIBLE:  ' Print to File  ', cursor=1",
+     "BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table  Print to File  '",
+     "     VISIBLE:  ' Print to File  ', cursor=1",
+     "SPEECH OUTPUT: 'Print'",
+     "SPEECH OUTPUT: 'Default button is Print'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Escape and wait for the location bar
@@ -15,39 +15,13 @@
 
 ########################################################################
-# Open the "File" menu and press U for the Page Setup dialog
+# Open the "File" menu and press P for the Print dialog
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py
==============================================================================